package backend

import (
	"cron_admin/app/constants/errorcode"
	"cron_admin/app/http/controllers"
	"cron_admin/app/http/entities/backend"
	"cron_admin/app/models/croncmdmodel"
	"cron_admin/app/models/cronusermodel"
	"cron_admin/app/services"
	cmd_services "cron_admin/app/services/cmd_service"
	userServices "cron_admin/app/services/user_service"
	"cron_admin/app/utils/helper"
	"cron_admin/app/utils/mapstructure"
	"github.com/gin-gonic/gin"
	"strconv"
	"strings"
)

func CronReportLogsList(c *gin.Context) {
	request := controllers.GetRequest(c).(*backend.CronReportLogsListRequest)
	count, reportLogsList, err := services.CronReportLogsList(request, request.Page, request.Limit)
	if err != nil {
		controllers.HandRes(c, nil, errorcode.ParamError)
	} else {
		var reportLogsListResponse []backend.CronReportLogsListResponse
		_ = mapstructure.DecodeWithTime(reportLogsList, &reportLogsListResponse, helper.DefaultFormatLayout)
		//	合并reportLogsListResponse下的所有user_id 并去重
		var userIds []string
		userIdsMap := make(map[int64]bool)
		var cmdIds []string
		cmdIdsMap := make(map[int64]bool)
		for _, v := range reportLogsListResponse {
			userIdsStr := strings.Split(v.UserId, ",")
			for _, userId := range userIdsStr {
				if userId != "" {
					if _, ok := userIdsMap[helper.StringToInt64(userId)]; ok {
						continue
					}
					userIdsMap[helper.StringToInt64(userId)] = true
					userIds = append(userIds, userId)
				}
			}
			if _, ok := cmdIdsMap[v.CmdId]; ok {
				continue
			}
			cmdIdsMap[v.CmdId] = true
			//	v.cmdId 转成string
			cmdIdStr := strconv.FormatInt(v.CmdId, 10)
			cmdIds = append(cmdIds, cmdIdStr)
		}
		_, userList, err := userServices.GetListByWhere(&backend.UserListRequest{UserIds: userIds}, 1, 100)
		if err != nil {
			return
		}
		userListMap := make(map[int64]cronusermodel.CronUser)
		for _, v := range userList {
			userListMap[int64(v.UserId)] = v
		}
		//	获取所有的cmd_id对应的CmdName
		_, cmdList, err := cmd_services.GetListByWhere(&backend.CmdListRequest{CmdIds: cmdIds}, 1, 100)
		if err != nil {
			return
		}
		cmdListMap := make(map[int64]croncmdmodel.CronCmd)
		for _, v := range cmdList {
			cmdListMap[int64(v.CmdId)] = v
		}
		for k, v := range reportLogsListResponse {
			userIdsStr := strings.Split(v.UserId, ",")
			var userNames []string
			for _, userId := range userIdsStr {
				if userId != "" {
					userNames = append(userNames, userListMap[helper.StringToInt64(userId)].Name)
				}
			}
			userNamesStr := strings.Join(userNames, ",")
			reportLogsListResponse[k].UserName = userNamesStr
			if cmdListMap != nil && cmdListMap[v.CmdId].CmdName != "" {
				reportLogsListResponse[k].CmdName = cmdListMap[v.CmdId].CmdName
			}
		}

		controllers.HandRes(c, gin.H{"data": reportLogsListResponse, "count": count}, err)
	}
}
